@@ -76,7 +76,7 @@ class HiveServer2Connection(Connection):
         # PEP 249
         raise NotSupportedError
 
-    def cursor(self, user=None, configuration=None, convert_types=True):
+    def cursor(self, user=None, configuration=None, convert_types=True, dictify=False):
         """Get a cursor from the HiveServer2 (HS2) connection.
 
         Parameters
@@ -109,7 +109,9 @@ class HiveServer2Connection(Connection):
                   self.service, session.handle,
                   session.config, session.hs2_protocol_version)
 
-        cursor = HiveServer2Cursor(session, convert_types=convert_types)
+        cursor_class = HiveServer2DictCursor if dictify else HiveServer2Cursor
+
+        cursor = cursor_class(session, convert_types=convert_types)
 
         if self.default_db is not None:
             log.info('Using database %s as default', self.default_db)
@@ -541,6 +543,18 @@ class HiveServer2Cursor(Cursor):
         self._wait_to_finish()
 
 
+class HiveServer2DictCursor(HiveServer2Cursor):
+    """The cursor that returns each element as a dictionary"""
+    def execute(self, operation, parameters=None, configuration=None):
+        super(self.__class__, self).execute(operation, parameters,
+                                            configuration)
+        self.fields = [d[0] for d in self.description]
+
+    def __next__(self):
+        record = super(self.__class__, self).__next__()
+        return dict(zip(self.fields, record))
+
+
 # This work builds off of:
 # 1. the Hue interface:
 #       hue/apps/beeswax/src/beeswax/server/dbms.py
